==> visualvm_2.0.6+dfsg.orig.tar.gz: visualvm-2.0.6/visualvm/heapviewer.truffle/src/org/graalvm/visualvm/heapviewer/truffle/TruffleObjectsWrapper.java <==
/*
 * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.graalvm.visualvm.heapviewer.truffle;

import java.util.Iterator;
import org.graalvm.visualvm.heapviewer.model.DataType;

/**
 *
 * @author Jiri Sedlacek
 */
public abstract class TruffleObjectsWrapper<O extends TruffleObject> {
    
    public static final DataType<TruffleObjectsWrapper> DATA_TYPE = new DataType<TruffleObjectsWrapper>(TruffleObjectsWrapper.class, null, null);
    
    
    public abstract String getType();
    
    public abstract int getObjectsCount();
    
    public abstract Iterator<O> getObjectsIterator();
    
    
    public static abstract class Simple extends TruffleObjectsWrapper {
        
        private final String type;
        
        private final int objectsCount;
        
        
        public Simple(String type, int objectsCount) {
            this.type = type;
            this.objectsCount = objectsCount;
        }
        
        
        @Override
        public final String getType() {
            return type;
        }
        
        @Override
        public final int getObjectsCount() {
            return objectsCount;
        }
        
    }
    
}

==> visualvm_2.2.orig.tar.gz: visualvm-2.2/visualvm/heapviewer.truffle/src/org/graalvm/visualvm/heapviewer/truffle/TruffleObjectsWrapper.java <==
/*
 * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 * 
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 * 
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 * 
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 * 
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */
package org.graalvm.visualvm.heapviewer.truffle;

import java.util.Iterator;
import org.graalvm.visualvm.heapviewer.model.DataType;

/**
 *
 * @author Jiri Sedlacek
 */
public abstract class TruffleObjectsWrapper<O extends TruffleObject> {
    
    public static final DataType<TruffleObjectsWrapper> DATA_TYPE = new DataType<>(TruffleObjectsWrapper.class, null, null);
    
    
    public abstract String getType();
    
    public abstract int getObjectsCount();
    
    public abstract Iterator<O> getObjectsIterator();
    
    
    public static abstract class Simple<O extends TruffleObject> extends TruffleObjectsWrapper<O> {
        
        private final String type;
        
        private final int objectsCount;
        
        
        public Simple(String type, int objectsCount) {
            this.type = type;
            this.objectsCount = objectsCount;
        }
        
        
        @Override
        public final String getType() {
            return type;
        }
        
        @Override
        public final int getObjectsCount() {
            return objectsCount;
        }
        
    }
    
}
